package glaukon.tutorials.tipcalc;

// Import statements let us use code that's not in our project's package.
import java.util.ArrayList;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.TextView;

public class Diner {

	// Declare the variables we'll need.
	// total does not include tip or tax.
	public double total;
	public ArrayList<EditText> orderList;
	public EditText etName;
	public EditText etFirstOrder;
	public ImageButton ibAddOrder;
	public TextView tvName;
	public TextView tvSplitBill;

	// This is the constructor. It runs when you instantiate a Diner.
	// It brings together all the Views that are associated with a new Diner object.
	public Diner(EditText et1, EditText et2, ImageButton ib, TextView tv1, TextView tv2) {
		// total starts off as 0, and is used to keep track of the sum of a Diner's orders.
		total = 0.0;
		// We also need an ArrayList to keep track of each Diner's orders.
		orderList = new ArrayList<EditText>();
		etName = et1;
		etFirstOrder = et2;
		ibAddOrder = ib;
		tvName = tv1;
		tvSplitBill = tv2;
		// Make sure to add the first order to orderList.
		orderList.add(etFirstOrder);
	}

	// This method sets the Text property of tvName to whatever the user changed the Text property of etName to.
	public void setName() {
		// We need to use toString because getText does not return a string.
		tvName.setText(etName.getText().toString());
	}

	// This method adds a new order to a Diner's orderList.
	public void newOrder(EditText newOrder) {
		orderList.add(newOrder);
	}

	// This method updates the Diner's total based its orderList.
	// It is run when the user changes focus from an EditText in orderList.
	public void updateTotal(EditText toBeUpdated) {
		// First, reset total
		total = 0.0;
		// Then, format the EditText that was just changed
		toBeUpdated.setText("$" + String.format("%,.2f", editTextToDouble(toBeUpdated)));
		// Finally, go through each order and add it to total. Use editTextToDouble to help.
		for (int i = 0; i < orderList.size(); i++) {
			total += editTextToDouble(orderList.get(i));
		}
	}

	// We used to have an overloaded updateTotal method here, but we no longer need it.
	// public void updateTotal() {
	// updateTotal(etFirstOrder);
	// }

	// This method converts what's inside an EditText to a double, and returns it.
	public double editTextToDouble(EditText et) {
		double db = 0.0;
		db = Double.parseDouble(et.getText().toString().replace("$", "").replace(",", ""));
		return db;
	}

	// This method uses the tip and tax MainActivity gets it to set the proper value for tvSplitBill.
	public void setTotalText(double tip, double tax) {
		tvSplitBill.setText("$" + String.format("%,.2f", total * (1 + tip) + total * tax));
	}
}